package handles

import (
	"fmt"
	"github.com/gorilla/mux"
	"github.com/louisevanderlith/kong"
	"github.com/rs/cors"
	"net/http"
	"strings"
)

func SetupRoutes(host, scrt, secureUrl string) http.Handler {
	r := mux.NewRouter()

	view := kong.ResourceMiddleware("leads.submissions.search", scrt, secureUrl, GetSubmissions)
	r.HandleFunc("/submission/{key:[0-9]+\\x60[0-9]+}", view).Methods(http.MethodGet)

	create := kong.ResourceMiddleware("leads.submissions.create", scrt, secureUrl, CreateSubmission)
	r.HandleFunc("/submission", create).Methods(http.MethodPost)

	corsOpts := cors.New(cors.Options{
		AllowedOrigins: []string{fmt.Sprintf("https://*%s", strings.TrimSuffix(host, "/"))}, //you service is available and allowed for this base url
		AllowedMethods: []string{
			http.MethodGet,
			http.MethodPost,
			http.MethodOptions,
			http.MethodHead,
		},
		AllowCredentials: true,
		AllowedHeaders: []string{
			"*", //or you can your header key values which you are using in your application
		},
	})

	return corsOpts.Handler(r)
}
